@@ -10,12 +10,13 @@
 use super::{
     files::{FileItem, FileMeta, FilesMap, RealPath},
     multimap::MultimapKeyValues,
-    nrs::{NrsMap, VersionHash},
+    nrs::NrsMap,
     register::{Entry, EntryHash},
     Safe, XorName,
 };
-pub use super::{ContentType, DataType, NativeUrl, XorUrlBase};
+pub use super::{ContentType, DataType, Scope, Url, VersionHash, XorUrlBase};
 use crate::{Error, Result};
+use bytes::Bytes;
 use log::{debug, info};
 use serde::{Deserialize, Serialize};
 use std::{collections::BTreeSet, path::Path};
@@ -44,7 +45,7 @@ pub enum SafeData {
     PublicBlob {
         xorurl: String,
         xorname: XorName,
-        data: Vec<u8>,
+        data: Bytes,
         media_type: Option<String>,
         metadata: Option<FileItem>,
         resolved_from: String,
@@ -243,7 +244,7 @@ impl Safe {
 
     async fn resolve_one_indirection(
         &self,
-        mut the_xor: NativeUrl,
+        mut the_xor: Url,
         metadata: Option<FileItem>,
         retrieve_data: bool,
         range: Range,
@@ -281,7 +282,7 @@ impl Safe {
                                 if FileMeta::filetype_is_file(file_type) {
                                     match file_item.get("link") {
                                         Some(link) => {
-                                            let new_target_xorurl = NativeUrl::from_url(link)?;
+                                            let new_target_xorurl = Url::from_url(link)?;
                                             let mut metadata = (*file_item).clone();
                                             Path::new(&path).file_name().map(|name| {
                                                 name.to_str().map(|str| {
@@ -480,7 +481,7 @@ impl Safe {
 
     async fn retrieve_blob(
         &self,
-        the_xor: &NativeUrl,
+        the_xor: &Url,
         retrieve_data: bool,
         media_type: Option<String>,
         metadata: &Option<FileItem>,
@@ -498,7 +499,7 @@ impl Safe {
                 .get_public_blob(the_xor.xorname(), range)
                 .await?
         } else {
-            vec![]
+            Bytes::new()
         };
 
         let safe_data = SafeData::PublicBlob {
@@ -540,12 +541,12 @@ fn gen_filtered_filesmap(urlpath: &str, files_map: &FilesMap, xorurl: &str) -> R
 }
 // // This contains information for the next step to be made
 // // in each iteration of the resolution process
-type NextStepInfo = (NativeUrl, Option<FileItem>);
+type NextStepInfo = (Url, Option<FileItem>);
 
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::{app::test_helpers::new_safe_instance, retry_loop, NativeUrl, Scope};
+    use crate::{app::test_helpers::new_safe_instance, retry_loop, Scope, Url};
     use anyhow::{anyhow, bail, Context, Result};
     use rand::{distributions::Alphanumeric, thread_rng, Rng};
     use std::io::Read;
@@ -557,7 +558,7 @@ mod tests {
             .files_container_create(Some("../testdata/"), None, true, false, false)
             .await?;
 
-        let safe_url = NativeUrl::from_url(&xorurl)?;
+        let safe_url = Url::from_url(&xorurl)?;
         let content = retry_loop!(safe.fetch(&xorurl, None));
         let (version0, _) = retry_loop!(safe.files_container_get(&xorurl));
 
@@ -601,7 +602,7 @@ mod tests {
         let _ = retry_loop!(safe.fetch(&xorurl, None));
         let (version0, _) = retry_loop!(safe.files_container_get(&xorurl));
 
-        let mut safe_url = NativeUrl::from_url(&xorurl)?;
+        let mut safe_url = Url::from_url(&xorurl)?;
         safe_url.set_content_version(Some(version0));
         let (_nrs_map_xorurl, _, _nrs_map) = safe
             .nrs_map_container_create(&site_name, &safe_url.to_string(), true, true, false)
@@ -652,7 +653,7 @@ mod tests {
         let _ = retry_loop!(safe.fetch(&xorurl, None));
         let (version0, _) = retry_loop!(safe.files_container_get(&xorurl));
 
-        let mut safe_url = NativeUrl::from_url(&xorurl)?;
+        let mut safe_url = Url::from_url(&xorurl)?;
         safe_url.set_content_version(Some(version0));
         let files_container_url = safe_url.to_string();
         let _ = safe
@@ -685,19 +686,19 @@ mod tests {
     #[tokio::test]
     async fn test_fetch_public_blob() -> Result<()> {
         let mut safe = new_safe_instance().await?;
-        let data = b"Something super immutable";
+        let data = Bytes::from("Something super immutable");
         let xorurl = safe
-            .files_store_public_blob(data, Some("text/plain"), false)
+            .files_store_public_blob(data.clone(), Some("text/plain"), false)
             .await?;
 
-        let safe_url = NativeUrl::from_url(&xorurl)?;
+        let safe_url = Url::from_url(&xorurl)?;
         let content = retry_loop!(safe.fetch(&xorurl, None));
         assert!(
             content
                 == SafeData::PublicBlob {
                     xorurl: xorurl.clone(),
                     xorname: safe_url.xorname(),
-                    data: data.to_vec(),
+                    data: data.clone(),
                     resolved_from: xorurl.clone(),
                     media_type: Some("text/plain".to_string()),
                     metadata: None,
@@ -711,7 +712,7 @@ mod tests {
                 == SafeData::PublicBlob {
                     xorurl: xorurl.clone(),
                     xorname: safe_url.xorname(),
-                    data: vec![],
+                    data: Bytes::new(),
                     resolved_from: xorurl,
                     media_type: Some("text/plain".to_string()),
                     metadata: None,
@@ -723,10 +724,10 @@ mod tests {
     #[tokio::test]
     async fn test_fetch_range_public_blob() -> Result<()> {
         let safe = new_safe_instance().await?;
-        let saved_data = b"Something super immutable";
+        let saved_data = Bytes::from("Something super immutable");
         let size = saved_data.len();
         let xorurl = safe
-            .files_store_public_blob(saved_data, Some("text/plain"), false)
+            .files_store_public_blob(saved_data.clone(), Some("text/plain"), false)
             .await?;
 
         // Fetch first half and match
@@ -734,7 +735,7 @@ mod tests {
         let content = retry_loop!(safe.fetch(&xorurl, fetch_first_half));
 
         if let SafeData::PublicBlob { data, .. } = &content {
-            assert_eq!(data.clone(), saved_data[0..size / 2].to_vec());
+            assert_eq!(data.clone(), saved_data.slice(0..size / 2).to_vec());
         } else {
             bail!("Content fetched is not a PublicBlob: {:?}", content);
         }
@@ -766,7 +767,7 @@ mod tests {
         let _ = retry_loop!(safe.fetch(&xorurl, None));
         let (version0, _) = retry_loop!(safe.files_container_get(&xorurl));
 
-        let mut safe_url = NativeUrl::from_url(&xorurl)?;
+        let mut safe_url = Url::from_url(&xorurl)?;
         safe_url.set_content_version(Some(version0));
         let (_nrs_map_xorurl, _, _nrs_map) = safe
             .nrs_map_container_create(&site_name, &safe_url.to_string(), true, true, false)
@@ -819,7 +820,7 @@ mod tests {
         let mut safe = new_safe_instance().await?;
         let xorname = rand::random();
         let type_tag = 575_756_443;
-        let xorurl = NativeUrl::encode(
+        let xorurl = Url::encode(
             xorname,
             None,
             type_tag,
@@ -860,10 +861,12 @@ mod tests {
     #[tokio::test]
     async fn test_fetch_public_blob_with_path() -> Result<()> {
         let safe = new_safe_instance().await?;
-        let data = b"Something super immutable";
-        let xorurl = safe.files_store_public_blob(data, None, false).await?;
+        let data = Bytes::from("Something super immutable");
+        let xorurl = safe
+            .files_store_public_blob(data.clone(), None, false)
+            .await?;
 
-        let mut safe_url = NativeUrl::from_url(&xorurl)?;
+        let mut safe_url = Url::from_url(&xorurl)?;
         let path = "/some_relative_filepath";
         safe_url.set_path(path);
         match safe.fetch(&safe_url.to_string(), None).await {
@@ -879,10 +882,10 @@ mod tests {
 
         // test the same but a file with some media type
         let xorurl = safe
-            .files_store_public_blob(data, Some("text/plain"), false)
+            .files_store_public_blob(data.clone(), Some("text/plain"), false)
             .await?;
 
-        let mut safe_url = NativeUrl::from_url(&xorurl)?;
+        let mut safe_url = Url::from_url(&xorurl)?;
         safe_url.set_path("/some_relative_filepath");
         let url_with_path = safe_url.to_string();
         match safe.fetch(&url_with_path, None).await {
