@@ -10,15 +10,16 @@
 mod nrs_map;
 
 pub use nrs_map::{DefaultRdf, NrsMap};
-pub use safe_network::url::VersionHash;
+pub use safe_network::url::{ContentType, VersionHash};
 
 use crate::{
     app::{
         consts::{CONTENT_ADDED_SIGN, CONTENT_DELETED_SIGN},
         Safe,
     },
-    Error, NativeUrl, Result, XorUrl,
+    Error, Result, Url, XorUrl,
 };
+use bytes::{Buf, Bytes};
 use log::{debug, info, warn};
 use std::collections::{BTreeMap, BTreeSet};
 
@@ -31,19 +32,16 @@ const ERROR_MSG_NO_NRS_MAP_FOUND: &str = "No NRS Map found at this address";
 pub type ProcessedEntries = BTreeMap<String, (String, String)>;
 
 impl Safe {
-    pub fn parse_url(url: &str) -> Result<NativeUrl> {
-        let safe_url = NativeUrl::from_url(&sanitised_url(url))?;
+    pub fn parse_url(url: &str) -> Result<Url> {
+        let safe_url = Url::from_url(&sanitised_url(url))?;
         Ok(safe_url)
     }
 
-    // Parses a safe:// URL and returns all the info in a NativeUrl instance.
-    // It also returns a second NativeUrl if the URL was resolved from an NRS-URL,
-    // this second NativeUrl instance contains the information of the parsed NRS-URL.
+    // Parses a safe:// URL and returns all the info in a Url instance.
+    // It also returns a second Url if the URL was resolved from an NRS-URL,
+    // this second Url instance contains the information of the parsed NRS-URL.
     // *Note* this is not part of the public API, but an internal helper function used by API impl.
-    pub(crate) async fn parse_and_resolve_url(
-        &self,
-        url: &str,
-    ) -> Result<(NativeUrl, Option<NativeUrl>)> {
+    pub(crate) async fn parse_and_resolve_url(&self, url: &str) -> Result<(Url, Option<Url>)> {
         let safe_url = Safe::parse_url(url)?;
         let orig_path = safe_url.path_decoded()?;
 
@@ -62,8 +60,8 @@ impl Safe {
             .pop()
             .ok_or_else(|| Error::ContentNotFound(format!("Failed to resolve {}", url)))?;
 
-        // Set the original path so we return the NativeUrl with it
-        let mut safe_url = NativeUrl::from_url(&safe_data.xorurl())?;
+        // Set the original path so we return the Url with it
+        let mut safe_url = Url::from_url(&safe_data.xorurl())?;
         safe_url.set_path(&orig_path);
 
         // If there is still one item in the chain, the first item is the NRS Map Container
@@ -71,7 +69,7 @@ impl Safe {
         if resolution_chain.is_empty() {
             Ok((safe_url, None))
         } else {
-            let nrsmap_xorul_encoder = NativeUrl::from_url(&resolution_chain[0].resolved_from())?;
+            let nrsmap_xorul_encoder = Url::from_url(&resolution_chain[0].resolved_from())?;
             Ok((safe_url, Some(nrsmap_xorul_encoder)))
         }
     }
@@ -117,6 +115,8 @@ impl Safe {
 
     /// # Create a NrsMapContainer.
     ///
+    /// The returned XorUrl contains the first version hash
+    ///
     /// ## Example
     ///
     /// ```rust,no_run
@@ -159,7 +159,7 @@ impl Safe {
             return Ok(("".to_string(), processed_entries, nrs_map));
         }
 
-        let nrs_xorname = NativeUrl::from_nrsurl(&nrs_url)?.xorname();
+        let nrs_xorname = Url::from_nrsurl(&nrs_url)?.xorname();
         debug!("XorName for \"{:?}\" is \"{:?}\"", &nrs_url, &nrs_xorname);
 
         // Store the serialised NrsMap in a Public Blob
@@ -175,11 +175,16 @@ impl Safe {
             name.as_bytes().to_owned(),
             nrs_map_xorurl.as_bytes().to_owned(),
         );
-        let _ = self
+        let entry_hash = &self
             .multimap_insert(&xorurl, entry, BTreeSet::new())
             .await?;
 
-        Ok((xorurl, processed_entries, nrs_map))
+        let mut tmp_url = Url::from_xorurl(&xorurl)?;
+        tmp_url.set_content_version(Some(VersionHash::from(entry_hash)));
+        tmp_url.set_content_type(ContentType::NrsMapContainer)?;
+        let new_xor_url = format!("{}", &tmp_url);
+
+        Ok((new_xor_url, processed_entries, nrs_map))
     }
 
     pub async fn nrs_map_container_remove(
@@ -285,13 +290,13 @@ impl Safe {
             ))
         })?;
         debug!("Deserialised NrsMap XOR-URL: {}", url);
-        let nrs_map_xorurl = NativeUrl::from_url(&url)?;
+        let nrs_map_xorurl = Url::from_url(&url)?;
 
         // Using the NrsMap XOR-URL we can now fetch the NrsMap and deserialise it
         let serialised_nrs_map = self.fetch_public_blob(&nrs_map_xorurl, None).await?;
 
         debug!("Nrs map v{} retrieved: {:?} ", version, &serialised_nrs_map);
-        let nrs_map = serde_json::from_str(&String::from_utf8_lossy(serialised_nrs_map.as_slice()))
+        let nrs_map = serde_json::from_str(&String::from_utf8_lossy(serialised_nrs_map.chunk()))
             .map_err(|err| {
                 Error::ContentError(format!(
                     "Couldn't deserialise the NrsMap stored in the NrsContainer: {:?}",
@@ -315,14 +320,14 @@ impl Safe {
         })?;
 
         let nrs_map_xorurl = self
-            .files_store_public_blob(serialised_nrs_map.as_bytes(), None, false)
+            .files_store_public_blob(Bytes::from(serialised_nrs_map), None, false)
             .await?;
 
         Ok(nrs_map_xorurl)
     }
 }
 
-fn validate_nrs_name(name: &str) -> Result<(NativeUrl, String)> {
+fn validate_nrs_name(name: &str) -> Result<(Url, String)> {
     // validate no slashes in name.
     if name.find('/').is_some() {
         let msg = "The NRS name/subname cannot contain a slash".to_string();
@@ -392,7 +397,7 @@ mod tests {
                 nrs_map.get_default()?,
                 &DefaultRdf::OtherRdf(def_data.clone())
             );
-            let decoder = NativeUrl::from_url(&xor_url)?;
+            let decoder = Url::from_url(&xor_url)?;
             assert_eq!(nrs_xorname, decoder.xorname());
             Ok(())
         } else {
